@@ -17,7 +17,7 @@ def http_get(url, user_agent, prams, time_out):
         import urllib
         data = urllib.parse.urlencode(prams)
         url = url + "?" + data
-        http = urllib3.PoolManager(timeout=time_out)
+        http = urllib3.PoolManager(timeout=time_out, cert_reqs='CERT_NONE')
         f = http.request(method='GET', url=url, headers={"User-Agent": user_agent})
         res_bytes = f.data
         msg = res_bytes.decode("utf-8")
